==> senior_design_system-2.2.16.tar.gz: lib/components/senior_evaluation/senior_evaluation.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

enum StatusChip {
  sent,
  answered,
  waiting,
}

enum StatusPill {
  exceededExpectations,
  fullyAttends,
  serveSatisfactorily,
  partiallyAttends,
  doesNotAttend,
}

enum StatusIconTag {
  exceededExpectations,
  fullyAttends,
  serveSatisfactorily,
  partiallyAttends,
  doesNotAttend,
}

@Deprecated('Use SeniorBadge instead')
class SeniorEvaluation extends StatelessWidget {
  late final Widget evaluation;

  SeniorEvaluation.pill({
    Key? key,
    required String label,
    required bool disabled,
    required StatusPill status,
  }) {
    evaluation = _Pill(
      label: label,
      disabled: disabled,
      status: status,
    );
  }

  SeniorEvaluation.iconTag({
    Key? key,
    required String label,
    required bool disabled,
    required StatusIconTag status,
  }) {
    evaluation = _IconTag(
      label: label,
      disabled: disabled,
      status: status,
    );
  }

  SeniorEvaluation.chip({
    Key? key,
    required String label,
    required StatusChip status,
  }) {
    evaluation = _Chip(
      label: label,
      status: status,
    );
  }

  @override
  Widget build(BuildContext context) {
    return evaluation;
  }
}

class _Chip extends StatelessWidget {
  _Chip({
    Key? key,
    required this.label,
    required this.status,
  }) : super(key: key);

  final String label;
  final StatusChip status;

  @override
  Widget build(BuildContext context) {
    final BoxDecoration _decoration = BoxDecoration(
      color: getColor(status: status),
      borderRadius: const BorderRadius.all(
        Radius.circular(6.0),
      ),
    );

    return Container(
      decoration: _decoration,
      child: Row(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Padding(
            padding: const EdgeInsets.all(4),
            child: Text(
              '$label',
              style: SeniorTypography.small(
                color: SeniorColors.pureBlack,
              ),
              textAlign: TextAlign.start,
            ),
          ),
        ],
      ),
    );
  }

  Color getColor({
    required StatusChip status,
  }) {
    if (status == StatusChip.sent) {
      return SeniorColors.manchesterColorGreen300;
    }

    if (status == StatusChip.answered) {
      return SeniorColors.manchesterColorBlue200;
    }

    if (status == StatusChip.waiting) {
      return SeniorColors.manchesterColorYellow400;
    }

    return Colors.transparent;
  }
}

class _Pill extends StatelessWidget {
  _Pill({
    Key? key,
    required this.label,
    required this.disabled,
    required this.status,
  }) : super(key: key);

  final String label;
  final bool disabled;
  final StatusPill status;

  @override
  Widget build(BuildContext context) {
    final BoxDecoration _decoration = BoxDecoration(
      color: disabled ? SeniorColors.secondaryColor400 : getColor(status: status),
      borderRadius: const BorderRadius.all(
        Radius.circular(50.0),
      ),
    );

    return Container(
      padding: const EdgeInsets.symmetric(
        horizontal: SeniorSpacing.xsmall,
        vertical: SeniorSpacing.xxxsmall,
      ),
      decoration: _decoration,
      child: Row(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Text(
            '$label',
            style: SeniorTypography.small(
              color: SeniorColors.pureWhite,
            ),
            textAlign: TextAlign.start,
          ),
        ],
      ),
    );
  }

  Color getColor({
    required StatusPill status,
  }) {
    if (status == StatusPill.exceededExpectations) {
      return SeniorColors.supportingColor;
    }

    if (status == StatusPill.fullyAttends) {
      return SeniorColors.primaryColor400;
    }

    if (status == StatusPill.serveSatisfactorily) {
      return SeniorColors.manchesterColorBlue400;
    }

    if (status == StatusPill.partiallyAttends) {
      return SeniorColors.manchesterColorYellow400;
    }

    if (status == StatusPill.doesNotAttend) {
      return SeniorColors.manchesterColorRed400;
    }

    return Colors.transparent;
  }
}

class _IconTag extends StatelessWidget {
  _IconTag({
    Key? key,
    required this.label,
    required this.disabled,
    required this.status,
  }) : super(key: key);

  final String label;
  final bool disabled;
  final StatusIconTag status;

  @override
  Widget build(BuildContext context) {
    final BoxDecoration _decoration = BoxDecoration(
      color: disabled ? SeniorColors.secondaryColor400 : getColor(status: status),
      borderRadius: const BorderRadius.all(
        Radius.circular(50.0),
      ),
    );

    return Container(
      padding: const EdgeInsets.symmetric(
        vertical: SeniorSpacing.xsmall,
        horizontal: SeniorSpacing.xsmall,
      ),
      decoration: _decoration,
      child: Row(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Icon(
            getIcon(status: status),
            color: SeniorColors.pureWhite,
            size: SeniorIconSize.small,
          ),
          const SizedBox(width: SeniorSpacing.xsmall),
          Text(
            '$label',
            style: SeniorTypography.small(
              color: SeniorColors.pureWhite,
            ),
          ),
        ],
      ),
    );
  }

  Color getColor({
    required StatusIconTag status,
  }) {
    if (status == StatusIconTag.exceededExpectations) {
      return SeniorColors.supportingColor;
    }

    if (status == StatusIconTag.fullyAttends) {
      return SeniorColors.primaryColor400;
    }

    if (status == StatusIconTag.serveSatisfactorily) {
      return SeniorColors.manchesterColorBlue400;
    }

    if (status == StatusIconTag.partiallyAttends) {
      return SeniorColors.manchesterColorYellow400;
    }

    if (status == StatusIconTag.doesNotAttend) {
      return SeniorColors.manchesterColorRed400;
    }

    return Colors.transparent;
  }

  IconData getIcon({
    required StatusIconTag status,
  }) {
    if (status == StatusIconTag.exceededExpectations) {
      return FontAwesomeIcons.faceLaugh;
    }

    if (status == StatusIconTag.fullyAttends) {
      return FontAwesomeIcons.faceLaughWink;
    }

    if (status == StatusIconTag.serveSatisfactorily) {
      return FontAwesomeIcons.faceSmileWink;
    }

    if (status == StatusIconTag.partiallyAttends) {
      return FontAwesomeIcons.faceSmile;
    }

    if (status == StatusIconTag.doesNotAttend) {
      return FontAwesomeIcons.faceMeh;
    }

    return FontAwesomeIcons.faceLaugh;
  }
}

==> senior_design_system-5.0.0.tar.gz: lib/components/senior_evaluation/senior_evaluation.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

enum StatusChip {
  sent,
  answered,
  waiting,
}

enum StatusPill {
  exceededExpectations,
  fullyAttends,
  serveSatisfactorily,
  partiallyAttends,
  doesNotAttend,
}

enum StatusIconTag {
  exceededExpectations,
  fullyAttends,
  serveSatisfactorily,
  partiallyAttends,
  doesNotAttend,
}

@Deprecated('Use SeniorBadge instead')
class SeniorEvaluation extends StatelessWidget {
  late final Widget evaluation;

  SeniorEvaluation.pill({
    Key? key,
    required String label,
    required bool disabled,
    required StatusPill status,
  }) {
    evaluation = _Pill(
      label: label,
      disabled: disabled,
      status: status,
    );
  }

  SeniorEvaluation.iconTag({
    Key? key,
    required String label,
    required bool disabled,
    required StatusIconTag status,
  }) {
    evaluation = _IconTag(
      label: label,
      disabled: disabled,
      status: status,
    );
  }

  SeniorEvaluation.chip({
    Key? key,
    required String label,
    required StatusChip status,
  }) {
    evaluation = _Chip(
      label: label,
      status: status,
    );
  }

  @override
  Widget build(BuildContext context) {
    return evaluation;
  }
}

class _Chip extends StatelessWidget {
  _Chip({
    Key? key,
    required this.label,
    required this.status,
  }) : super(key: key);

  final String label;
  final StatusChip status;

  @override
  Widget build(BuildContext context) {
    final BoxDecoration _decoration = BoxDecoration(
      color: getColor(status: status),
      borderRadius: const BorderRadius.all(
        Radius.circular(6.0),
      ),
    );

    return Container(
      decoration: _decoration,
      child: Row(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Padding(
            padding: const EdgeInsets.all(4),
            child: Text(
              '$label',
              style: SeniorTypography.small(
                color: SeniorColors.pureBlack,
              ),
              textAlign: TextAlign.start,
            ),
          ),
        ],
      ),
    );
  }

  Color getColor({
    required StatusChip status,
  }) {
    if (status == StatusChip.sent) {
      return SeniorColors.manchesterColorGreen300;
    }

    if (status == StatusChip.answered) {
      return SeniorColors.manchesterColorBlue200;
    }

    if (status == StatusChip.waiting) {
      return SeniorColors.manchesterColorYellow400;
    }

    return Colors.transparent;
  }
}

class _Pill extends StatelessWidget {
  _Pill({
    Key? key,
    required this.label,
    required this.disabled,
    required this.status,
  }) : super(key: key);

  final String label;
  final bool disabled;
  final StatusPill status;

  @override
  Widget build(BuildContext context) {
    final BoxDecoration _decoration = BoxDecoration(
      color:
          disabled ? SeniorColors.secondaryColor400 : getColor(status: status),
      borderRadius: const BorderRadius.all(
        Radius.circular(50.0),
      ),
    );

    return Container(
      padding: const EdgeInsets.symmetric(
        horizontal: SeniorSpacing.xsmall,
        vertical: SeniorSpacing.xxxsmall,
      ),
      decoration: _decoration,
      child: Row(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Text(
            '$label',
            style: SeniorTypography.small(
              color: SeniorColors.pureWhite,
            ),
            textAlign: TextAlign.start,
          ),
        ],
      ),
    );
  }

  Color getColor({
    required StatusPill status,
  }) {
    if (status == StatusPill.exceededExpectations) {
      return SeniorColors.supportingColor;
    }

    if (status == StatusPill.fullyAttends) {
      return SeniorColors.primaryColor400;
    }

    if (status == StatusPill.serveSatisfactorily) {
      return SeniorColors.manchesterColorBlue400;
    }

    if (status == StatusPill.partiallyAttends) {
      return SeniorColors.manchesterColorYellow400;
    }

    if (status == StatusPill.doesNotAttend) {
      return SeniorColors.manchesterColorRed400;
    }

    return Colors.transparent;
  }
}

class _IconTag extends StatelessWidget {
  _IconTag({
    Key? key,
    required this.label,
    required this.disabled,
    required this.status,
  }) : super(key: key);

  final String label;
  final bool disabled;
  final StatusIconTag status;

  @override
  Widget build(BuildContext context) {
    final BoxDecoration _decoration = BoxDecoration(
      color:
          disabled ? SeniorColors.secondaryColor400 : getColor(status: status),
      borderRadius: const BorderRadius.all(
        Radius.circular(50.0),
      ),
    );

    return Container(
      padding: const EdgeInsets.symmetric(
        vertical: SeniorSpacing.xsmall,
        horizontal: SeniorSpacing.xsmall,
      ),
      decoration: _decoration,
      child: Row(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Icon(
            getIcon(status: status),
            color: SeniorColors.pureWhite,
            size: SeniorIconSize.small,
          ),
          const SizedBox(width: SeniorSpacing.xsmall),
          Text(
            '$label',
            style: SeniorTypography.small(
              color: SeniorColors.pureWhite,
            ),
          ),
        ],
      ),
    );
  }

  Color getColor({
    required StatusIconTag status,
  }) {
    if (status == StatusIconTag.exceededExpectations) {
      return SeniorColors.supportingColor;
    }

    if (status == StatusIconTag.fullyAttends) {
      return SeniorColors.primaryColor400;
    }

    if (status == StatusIconTag.serveSatisfactorily) {
      return SeniorColors.manchesterColorBlue400;
    }

    if (status == StatusIconTag.partiallyAttends) {
      return SeniorColors.manchesterColorYellow400;
    }

    if (status == StatusIconTag.doesNotAttend) {
      return SeniorColors.manchesterColorRed400;
    }

    return Colors.transparent;
  }

  IconData getIcon({
    required StatusIconTag status,
  }) {
    if (status == StatusIconTag.exceededExpectations) {
      return FontAwesomeIcons.faceLaugh;
    }

    if (status == StatusIconTag.fullyAttends) {
      return FontAwesomeIcons.faceLaughWink;
    }

    if (status == StatusIconTag.serveSatisfactorily) {
      return FontAwesomeIcons.faceSmileWink;
    }

    if (status == StatusIconTag.partiallyAttends) {
      return FontAwesomeIcons.faceSmile;
    }

    if (status == StatusIconTag.doesNotAttend) {
      return FontAwesomeIcons.faceMeh;
    }

    return FontAwesomeIcons.faceLaugh;
  }
}
